@@ -27,7 +27,7 @@ def test_get_info_url(mock):
 
 @patch_get_content('fmelli.html')
 def test_get_page_info():
-    d = Instrument(1).get_page_info()
+    d = Instrument(1).get_page_data(True, True)
     trade_history = d.pop('trade_history')
     related_companies = d.pop('related_companies')
     assert d == {
@@ -116,9 +116,7 @@ def test_get_page_info():
 
 @patch_get_content('dey.html')
 def test_get_page_info_no_free_float():
-    d = Instrument(1).get_page_info()
-    d.pop('related_companies')  # too long
-    d.pop('trade_history')  # too long
+    d = Instrument(1).get_page_data()
     assert d == {
         'bvol': 2231446,
         'cisin': 'IRO3BDYZ0003',
@@ -145,9 +143,7 @@ def test_get_page_info_no_free_float():
 
 @patch_get_content('kala.html')
 def test_get_page_info_no_eps():
-    d = Instrument(1).get_page_info()
-    d.pop('related_companies')  # too long
-    d.pop('trade_history')  # too long
+    d = Instrument(1).get_page_data()
     assert d == {
         'bvol': 1306165,
         'cisin': 'IRO1KALA0001',
@@ -174,7 +170,7 @@ def test_get_page_info_no_eps():
 
 @patch_get_content('khgostar.html')
 def test_get_page_info_no_sector_pe():
-    d = Instrument(1).get_page_info()
+    d = Instrument(1).get_page_data()
     assert d.items() >= {
         'tmin': 3670.0
         , 'tmax': 4050.0
@@ -197,7 +193,7 @@ def test_get_page_info_no_sector_pe():
 
 @patch_get_content('dara_yekom.txt')
 def test_dara1_instant():
-    assert Instrument(1).get_info(index=True) == {
+    assert Instrument(1).get_info(index=True, orders=True) == {
         'derivatives_status': 'F',
         'derivatives_tno': 7864,
         'derivatives_tval': 150982456491.0,
@@ -251,7 +247,7 @@ def test_dara1_instant():
 
 @patch_get_content('asam.txt')
 def test_asam_instant():
-    assert Instrument(1).get_info() == {
+    assert Instrument(1).get_info(orders=True) == {
         'status': 'A '
         , 'last_info_datetime': datetime(2020, 11, 11, 12, 28, 17)
         , 'nav': 95630
@@ -294,33 +290,15 @@ def test_negin_instant():
         , 'nav': 12190
         , 'nav_datetime': jdatetime(1398, 12, 29, 16, 0)
         , 'pc': 50110
-        , 'pd1': 50000
-        , 'pd2': 41000
-        , 'pd3': 20000
         , 'pf': 50010
         , 'pl': 50000
         , 'pmax': 50000
         , 'pmin': 50700
-        , 'po1': 50700
-        , 'po2': 50750
-        , 'po3': 50950
         , 'py': 50010
-        , 'qd1': 81526
-        , 'qd2': 1000
-        , 'qd3': 10620
-        , 'qo1': 29016
-        , 'qo2': 99
-        , 'qo3': 50000
         , 'timestamp': '12:29:37'
         , 'tno': 29
         , 'tval': 1408671580
-        , 'tvol': 28109
-        , 'zd1': 1
-        , 'zd2': 1
-        , 'zd3': 2
-        , 'zo1': 3
-        , 'zo2': 1
-        , 'zo3': 1}
+        , 'tvol': 28109}
 
 
 @patch_get_content('fmelli.txt')
@@ -399,33 +377,15 @@ VSKHOOZ = {
     'status': 'IS'
     , 'last_info_datetime': datetime(2021, 1, 20, 6, 42, 18)
     , 'pc': 67818
-    , 'pd1': 0
-    , 'pd2': 0
-    , 'pd3': 0
     , 'pf': 0
     , 'pl': 67810
     , 'pmax': 0
     , 'pmin': 0
-    , 'po1': 74939
-    , 'po2': 74946
-    , 'po3': 75000
     , 'py': 67818
-    , 'qd1': 0
-    , 'qd2': 0
-    , 'qd3': 0
-    , 'qo1': 44000
-    , 'qo2': 405
-    , 'qo3': 7500
     , 'timestamp': '06:42:18'
     , 'tno': 0
     , 'tval': 0
-    , 'tvol': 0
-    , 'zd1': 0
-    , 'zd2': 0
-    , 'zd3': 0
-    , 'zo1': 1
-    , 'zo2': 1
-    , 'zo3': 1}
+    , 'tvol': 0}
 
 
 @patch_get_content('vskhooz_short_response.txt')
@@ -468,7 +428,7 @@ def test_vsadid():
 @patch_get_content('search_firuze.txt')
 def test_from_search_with_numeric_description():
     # note the "30" in فيروزه - صندوق شاخص30 شركت فيروزه- سهام
-    assert Instrument.from_search('فیروزه').id == 66036975502302203
+    assert Instrument.from_search('فیروزه').ins_code == 66036975502302203
 
 
 def test_repr():
@@ -515,6 +475,24 @@ def test_get_client_type():
 
 
 def test_parse_index():
+    # no tse_value
+    assert _parse_index("00/1/14 06:40:12,F,1294521.64,<div class='mn'>(8671.45)</div>,,0.00,0.00,0,C,0.00,0.00,0,C,0.00,0.00,0,") == {
+        'derivatives_status': 'C',
+        'derivatives_tno': 0,
+        'derivatives_tval': 0.0,
+        'derivatives_tvol': 0.0,
+        'market_last_transaction': jdatetime(1300, 1, 14, 6, 40, 12),
+        'otc_status': 'C',
+        'otc_tno': 0,
+        'otc_tval': 0.0,
+        'otc_tvol': 0.0,
+        'tse_index': 1294521.64,
+        'tse_index_change': -8671.45,
+        'tse_status': 'F',
+        'tse_tno': 0.0,
+        'tse_tval': 0.0,
+        'tse_tvol': 0.0}
+
     assert {
         'derivatives_status': 'N',
         'derivatives_tno': 2621,
