@@ -19,8 +19,8 @@ GET = Session().get
 
 FARSI_NORM = ''.maketrans('يك', 'یک')
 F = r'(-?\d+(?:\.\d+)?)'  # float pattern
-# This regex is generated using page_vars_regex_generator.py.
-# Fix and update that script before making changes this regex.
+# This regex is generated using dev/page_vars_regex_generator.py.
+# Fix and update that script before making changes.
 PAGE_VARS = rc(
     "TopInst='(?P<TopInst>[^,]*)',"
     "LVal18AFC='[^,]*',"
@@ -77,50 +77,48 @@ def fa_norm_text(url) -> str:
 
 class Instrument:
 
-    __slots__ = 'id', 'isin', 'l13', 'l18'
+    __slots__ = 'ins_code', 'l18', 'l30'
 
     def __init__(self, id: Union[int, str]):
         try:
-            self.id, self.l13, self.l18, self.isin = KNOWN_IDS[id]
+            self.ins_code, self.l18, self.l30 = KNOWN_IDS[id]
         except KeyError:
             if isinstance(id, int):
-                self.id = id
-                self.l13 = self.l18 = self.isin = None
+                self.ins_code = id
+                self.l18 = self.l30 = None
                 return
             raise KeyError(
                 'id not found in KNOWN_IDS, try Instrument.from_search')
 
     def __repr__(self):
-        if self.l13 is None:
-            return f'Instrument({self.id})'
-        return f"Instrument('{self.l13}')"
+        if self.l18 is None:
+            return f'Instrument({self.ins_code})'
+        return f"Instrument('{self.l18}')"
 
     def __eq__(self, other):
-        return self.id == other.id
+        return self.ins_code == other.ins_code
 
     def __hash__(self):
-        return self.id
+        return self.ins_code
 
-    def get_page_info(self) -> dict:
+    def get_page_data(self, trade_history=False, related_companies=False) -> dict:
         """Return the static info found on instrument's page.
 
+        :param trade_history: include trade_history in the result.
+        :param related_companies: parse and include related_companies.
         For the meaning of keys see:
             https://cdn.tsetmc.com/Site.aspx?ParTree=151713
         """
-        text = fa_norm_text(f'http://tsetmc.com/Loader.aspx?ParTree=151311&i={self.id}')
+        text = fa_norm_text(f'http://tsetmc.com/Loader.aspx?ParTree=151311&i={self.ins_code}')
         m = PAGE_VARS(text)
         title_match = TITLE_FULLMATCH(m['Title'])
         free_float = m['KAjCapValCpsIdx']
         eps = m['EstimatedEPS']
         sector_pe = m['SectorPE']
-        trade_history = literal_eval(STR_TO_NUM(TRADE_HISTORY(text)[1]))
-        trade_history = DataFrame(trade_history, columns=('date', 'pc', 'py', 'pmin', 'pmax', 'tno', 'tvol', 'tval'))
-        trade_history['date'] = to_datetime(trade_history['date'], format='%Y%m%d')
-        trade_history.set_index('date', inplace=True)
-        return {
+        result = {
             'bvol': int(m['BaseVol']),
             'cisin': m['CIsin'],
-            'cs': int(m['CSecVal'].lstrip()),
+            'cs': int(m['CSecVal']),
             'eps': int(eps) if eps else None,
             'flow': int(m['Flow']),
             'free_float': int(free_float) if free_float else None,
@@ -130,20 +128,28 @@ class Instrument:
             'l30': title_match[1],
             'market': title_match[2],
             'month_average_volume': int(m['QTotTran5JAvg']),
-            'related_companies': literal_eval(STR_TO_NUM(RELATED_COMPANIES(text)[1])),
             'sector_name': m['LSecVal'],
             'sector_pe': float(sector_pe) if sector_pe else None,
             'tmax': float(m['PSGelStaMax']),
             'tmin': float(m['PSGelStaMin']),
-            'trade_history': trade_history,
             'week_max': float(m['MaxWeek']),
             'week_min': float(m['MinWeek']),
             'year_max': float(m['MaxYear']),
             'year_min': float(m['MinYear']),
             'z': int(m['ZTitad']),
         }  # todo: add 'codal_data'
+        if related_companies:
+            result['related_companies'] = literal_eval(
+                STR_TO_NUM(RELATED_COMPANIES(text)[1]))
+        if trade_history:
+            th = literal_eval(STR_TO_NUM(TRADE_HISTORY(text)[1]))
+            th = DataFrame(th, columns=('date', 'pc', 'py', 'pmin', 'pmax', 'tno', 'tvol', 'tval'))
+            th['date'] = to_datetime(th['date'], format='%Y%m%d')
+            th.set_index('date', inplace=True)
+            result['trade_history'] = th
+        return result
 
-    def get_info(self, orders=True, index=False) -> dict:
+    def get_info(self, orders=False, index=False) -> dict:
         """Get info using instinfodata.aspx module.
 
         :keyword orders: parse orders and include related values.
@@ -155,7 +161,7 @@ class Instrument:
         text = get_content(
             f'http://www.tsetmc.com/tsev2/data/instinfodata.aspx'
             # &e=1 parameter is required to get NAV
-            f'?i={self.id}&c=&e=1').decode()
+            f'?i={self.ins_code}&c=&e=1').decode()
         # the _s are unknown
         # todo: fix not enough valus to unpack
         try:
@@ -187,7 +193,7 @@ class Instrument:
 
     def get_trade_history(self, top: int) -> DataFrame:
         content = get_content(
-            f'http://www.tsetmc.com/tsev2/data/InstTradeHistory.aspx?i={self.id}&Top={top}')
+            f'http://www.tsetmc.com/tsev2/data/InstTradeHistory.aspx?i={self.ins_code}&Top={top}')
         df = read_csv(
             BytesIO(content)
             , sep='@'
@@ -204,7 +210,7 @@ class Instrument:
         In column names `n_` prefix stands for natural and `l_` for legal.
         """
         return read_csv(
-            BytesIO(get_content(f'http://www.tsetmc.com/tsev2/data/clienttype.aspx?i={self.id}'))
+            BytesIO(get_content(f'http://www.tsetmc.com/tsev2/data/clienttype.aspx?i={self.ins_code}'))
             , lineterminator=b';'
             , names=(
                 'date'
@@ -215,7 +221,7 @@ class Instrument:
 
     def get_identification(self) -> DataFrame:
         """Return the information available in the identification (شناسه) tab."""
-        text = fa_norm_text(f'http://www.tsetmc.com/Loader.aspx?Partree=15131M&i={self.id}')
+        text = fa_norm_text(f'http://www.tsetmc.com/Loader.aspx?Partree=15131M&i={self.ins_code}')
         return read_html(text, index_col=0)[0]
 
     @staticmethod
@@ -354,7 +360,6 @@ def _parse_index(s: str) -> dict:
         , 'tse_status': tse_status
         , 'tse_index': float(tse_index)
         , 'tse_index_change': tse_index_change
-        , 'tse_value': float(tse_value)
         , 'tse_tvol': float(tse_tvol)
         , 'tse_tval': float(tse_tval)
         , 'tse_tno': float(tse_tval)
@@ -366,6 +371,8 @@ def _parse_index(s: str) -> dict:
         , 'derivatives_tvol': float(derivatives_tvol)
         , 'derivatives_tval': float(derivatives_tval)
         , 'derivatives_tno': int(derivatives_tno)}
+    if tse_value:
+        result['tse_value'] = float(tse_value)
     if (m3 := index_change_match[3]) is not None:
         result['tse_index_change_percent'] = float(m3)
     return result
